#ifndef SP_TEXT_EDIT_H
#define SP_TEXT_EDIT_H

/**
 * \brief text-edit
 *
 * Text editing and font changes
 *
 */

void sp_text_edit_dialog (void);
void sp_text_edit_dialog_default_set_insensitive (); //FIXME: Replace trough a verb
 
#endif

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
